netapp_ontap.models.application_lun_object API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.application_lun_object`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ApplicationLunObjectSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ApplicationLunObject object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `creation_timestamp GET`

    LUN creation time

  `path GET`

    LUN path

  `size GET`

    LUN size

  `uuid GET`

    LUN UUID